@@ -5,7 +5,7 @@
 # more info on the M3U file format available here:
 # http://n4k3d.com/the-m3u-file-format/
 
-from soco_cli.utils import error_and_exit
+from soco_cli.utils import error_report
 
 
 class Track:
@@ -15,27 +15,20 @@ class Track:
         self.path = path
 
 
-"""
-    song info lines are formatted like:
-    EXTINF:419,Alice In Chains - Rotten Apple
-    length (seconds)
-    Song title
-    file name - relative or absolute path of file
-"""
+# song info lines are formatted like:
+# EXTINF:419,Alice In Chains - Rotten Apple
+# length (seconds)
+# Song title
+# file name - relative or absolute path of file
 
 
 def parse_m3u(m3u_file):
     with open(m3u_file, "r") as infile:
-        """
-        Parse file contents. Files with an M3U/M3U8 extension must follow conventions.
-        """
-
+        # Parse file contents. Files with an M3U/M3U8 extension must follow conventions.
         if m3u_file.lower().endswith(".m3u") or m3u_file.lower().endswith(".m3u8"):
             line = infile.readline()
             if not line.startswith("#EXTM3U"):
-                error_and_exit(
-                    "File '{}' lacks '#EXTM3U' as first line".format(m3u_file)
-                )
+                error_report("File '{}' lacks '#EXTM3U' as first line".format(m3u_file))
                 return None
 
         playlist = []
